@@ -11,8 +11,8 @@ pub enum Event {
     RefreshPreview(PreviewSize),
     ChangePreviewSize(PreviewSize),
     ImageEdit(ImageOperation),
-    StartSelection((i32, i32)),
-    DragSelection((i32, i32)),
+    StartSelection((u32, u32)),
+    DragSelection((u32, u32)),
     SaveCurrentImage(Option<PathBuf>),
     DeleteCurrentImage,
     EndSelection,
